{% extends "_base.html" %} {% import 'tables/_macros.html' as table_macros %} {% block body %} {% if error %}
{{ error.message }}
{% else %} {{ table_macros.table_nav(table_id, 'history') }}
{% for revision in table_history.revisions %}

##

- timestamp: {{ revision.timestamp }}
- operation: {{ revision.operation }}
- operation parameters

{% for param_key, param_val in revision.operation_parameters.items() %}
- {{ param_key }}: {{ param_val }}
{% endfor %}

- operation metrics

{% for metric_key, metric_val in revision.operation_metrics.items() %}
- {{ metric_key }}: {{ metric_val }}
{% endfor %}

- client version: {{ revision.client_version }}

{% endfor %}
{% endif %} {% endblock %}